# ESTIMATES THE QUANTITY OF WILDLIFE OR FISH CONSUMED AMONG HOUSEHOLDS THAT CONSUMED IN 2018
## Direct method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)

#focus on direct questions 
## food items:
# fish; turtle; wild meat (wild_meat here refers to mammals and birds only)

ind=which(dat$consumption_food_type=='wild_meat' & dat$questionnaire_type=="direct_only")
dat1=dat[ind,] 
unique(dat1$consumption_food_type)

#remove NA's from covariates and response variables
pred=c('cons_amount_2018','tot_days_2018')
apply(is.na(dat1[,pred]),2,sum)
k=apply(is.na(dat1[,pred]),1,sum)
table(k)
cond=k==0 & !is.na(dat1$cons_amount_2018) & dat1$cons_amount_2018>0 & dat1$cons_season==1
dat2=dat1[cond,]; dim(dat1); dim(dat2)

#basic settings
ntown=max(dat2$town.id)

#fix response and cons_season variables
unique(dat2$cons_amount_2018);
dat2$cons_amount_2018=dat2$cons_amount_2018*2 #to ensure that we have integer numbers
#-------------------
#direct question, sensitive item
y=dat2$cons_amount_2018
size=dat2$tot_days_2018
y.lfact=lfactorial(y)
nobs=length(y)
k=rep(1,nobs)
town.id=dat2$town.id
#-------------------
#data for jags
dat1=list(y=y,nobs=nobs,town.id=town.id,k=k,size=size,y.lfact=y.lfact,ntowns=ntown)

#set parameters to track
params=c("rate",'n')

# MCMC settings 
n.iter <- 50000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 5000  

#fit the model
setwd('C:\\models_jags')
model=jags(model.file='reg hurdle NB dq city.R',
           parameters.to.save=params,data=dat1,
           n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
           DIC=TRUE,parallel=TRUE)
summary(model)

#--------------------------------------------
#calculate average consumption in units of wild_meat per month during the high season
avg.consump=numeric()
for (i in 1:ntown){
  mu=model$sims.list$rate[,i]*30
  p=model$sims.list$n/(model$sims.list$n+mu)
  correction=1/(1-(p^model$sims.list$n))
  tmp=mu*correction
  avg.consump=cbind(avg.consump,tmp)
}

#adjust for the fact that amount_2018 was multiplied by 2
avg.consump1=avg.consump/2

#summarize results
media=apply(avg.consump1,2,mean)
ci=apply(avg.consump1,2,quantile,c(0.025,0.25, 0.75,0.975))
fim=data.frame(media=media,lo=ci[1,],first=ci[2,],second=ci[3,],hi=ci[4,])
rownames(fim)=paste0('town.type',1:3)
fim

setwd('C:\\results')

write.csv(fim,'rate hurdle NB dq_wild_meat.csv')
