# ESTIMATES THE QUANTITY OF WILDLIFE OR FISH CONSUMED AMONG HOUSEHOLDS THAT CONSUMED IN 2018
## Indirect method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)

#focus on indirect questions
## food items:
# acai_fish; pamonha_turtle; babaca_wild_meat (wild_meat here refers to mammals and birds only)

ind=which(dat$consumption_food_type%in%c('bacaba','bacaba_wild_meat'))
dat1=dat[ind,] 
unique(dat1$consumption_food_type)

#remove NA's from covariates and response variables
pred=c('cons_amount_2018','tot_days_2018')
apply(is.na(dat1[,pred]),2,sum)
k=apply(is.na(dat1[,pred]),1,sum)
table(k)
cond=k==0 & !is.na(dat1$cons_amount_2018) & dat1$cons_amount_2018>0 & dat1$cons_season==1
dat2=dat1[cond,]; dim(dat1); dim(dat2)

#basic settings
ntown=max(dat2$town.id)
table(dat2$cons_amount_2018)
#fix response and cons_season variables
unique(dat2$cons_amount_2018)
dat2$cons_amount_2018=dat2$cons_amount_2018*2 #to ensure that we have integer numbers
#-------------------
#direct question, non-sensitive item
cond=dat2$consumption_food_type=='bacaba'; 
ns=dat2[cond,]; dim(ns) 
y.ns=ns$cons_amount_2018
size.ns=ns$tot_days_2018
season.ns=ns$cons_season
y.ns.lfact=lfactorial(y.ns)
nobs.ns=length(y.ns)
k.ns=rep(1,nobs.ns)
town.id.ns=ns$town.id
#-------------------
#indirect question (iq)
cond=dat2$consumption_food_type=='bacaba_wild_meat'; 
iq=dat2[cond,]; dim(iq) 
y.iq=iq$cons_amount_2018
size.iq=iq$tot_days_2018
season.iq=iq$cons_season
y.iq.lfact=lfactorial(y.iq)
nobs.iq=length(y.iq)
k.iq=rep(1,nobs.iq)
town.id.iq=iq$town.id
#-------------------
#data for jags
pi.s=4/6
dat3=list(season.ns=season.ns,y.ns=y.ns,nobs.ns=nobs.ns,town.id.ns=town.id.ns,k.ns=k.ns,size.ns=size.ns,y.ns.lfact=y.ns.lfact,
          season.iq=season.iq,y.iq=y.iq,nobs.iq=nobs.iq,town.id.iq=town.id.iq,k.iq=k.iq,size.iq=size.iq,y.iq.lfact=y.iq.lfact,
          ntowns=ntown,pi.s=pi.s)

#set parameters to track
params=c("rate.ns",'rate.si','n.all')

# MCMC settings 
n.iter <- 50000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 5000  
    
#fit the model
setwd('C:\\models_jags')
model=jags(model.file='reg hurdle NB iq city.R',
               parameters.to.save=params,data=dat3,
               n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
               DIC=TRUE,parallel=TRUE)

summary(model)

#--------------------------------------------
table(dat1$tot_days_2018)

#calculate average consumption in units of wild_meat per month during the high season
avg.consump=numeric()
for (i in 1:ntown){
  mu=model$sims.list$rate.si[,i]*30
  p=model$sims.list$n.all/(model$sims.list$n.all+mu)
  correction=1/(1-(p^model$sims.list$n.all))
  tmp=mu*correction
  avg.consump=cbind(avg.consump,tmp)
}

#adjust for the fact that amount_2018 was multiplied by 2
avg.consump1=avg.consump/2

#summarize results
media=apply(avg.consump1,2,mean)
ci=apply(avg.consump1,2,quantile,c(0.025,0.25, 0.75,0.975))
fim=data.frame(media=media,lo=ci[1,],first=ci[2,],second=ci[3,],hi=ci[4,])
rownames(fim)=paste0('town.type',1:3)
fim

setwd('C:\\results')

write.csv(fim,'rate hurdle NB iq_wild_meat.csv')
