# ESTIMATES THE PROPORTION OF HOUSEHOLDS THAT CONSUMED WILDLIFE OR FISH IN 2018
## Direct method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)
table(dat[,c('consumption_now_2018','consumption_food_type')],useNA ='always') 

#focus on direct questions 
## food items:
# fish; turtle; wild meat (wild_meat here refers to mammals and birds only)

ind=which(dat$consumption_food_type=='wild_meat' & dat$questionnaire_type=="direct_only")
dat1=dat[ind,]; dim(dat1) 
dat1$y=dat1$consumption_now_2018
unique(dat1$consumption_food_type)

table(dat1$cons_season,useNA = 'always')
#--------------------------------------------
#remove observations with missing covariate and/or response variables
covs=c('town.id')
apply(is.na(dat1[,c(covs,'y')]),2,sum)
k=apply(is.na(dat1[,c(covs,'y')]),1,sum)
table(k)
cond=k==0
dat2=dat1[cond,]; dim(dat1); dim(dat2)
nparam=length(covs)
ntown=max(dat2$town.id)
cond=!is.na(dat2$cons_season) & dat2$cons_season!=0
dat3=dat2[cond,]; dim(dat2); dim(dat3)
#-------------------
#data for direct question
table(dat3[,c('town.id')])
#season=dat3$cons_season; unique(season)
y=dat3$y; table(y,useNA ='always')
n=length(y)
town=dat3$town.id; unique(town)
#-------------------

dat4=list(y=y,n=n,town=town,ntowns=ntown)

#set parameters to track
params=c('prob')

# MCMC settings 
n.iter <- 50000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 5000  

#fit the model
setwd('C:\\Users\\wchaves\\OneDrive - Virginia Tech\\Princeton_work\\Willa\\research_2018\\analysis\\analysis_method_paper\\models_methods_Ecological Applications\\repository\\models_jags')
model=jags(model.file='logistic direct city high season.R',
           parameters.to.save=params,data=dat4,
           n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
           DIC=TRUE,parallel=TRUE)
summary(model)
#--------------------------------------------
setwd('C:\\results')

#look at results
res=model$summary
pi.estim=as.data.frame(res[,c('mean','2.5%','50%','97.5%','Rhat','overlap0')])

#export summary of results
write.csv(pi.estim,'pi logistic dq_wild_meat.csv')