# ESTIMATES THE PROPORTION OF HOUSEHOLDS THAT CONSUMED WILDLIFE OR FISH IN 2018
## Indirect method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)

table(dat[,c('consumption_now_2018','consumption_food_type')],useNA ='always') 

table(dat$town.id)

#focus on indirect questions
## food items:
# acai_fish; pamonha_turtle; babaca_wild_meat (wild_meat here refers to mammals and birds only)

ind=which(dat$consumption_food_type%in%c('bacaba','bacaba_wild_meat'))
dat1=dat[ind,] 
dat1$y=dat1$consumption_now_2018
unique(dat1$consumption_food_type)

table(dat1$cons_season,useNA = 'always')
#--------------------------------------------
#remove observations with missing covariate and/or response variables
covs=c('town.id')
apply(is.na(dat1[,c(covs,'y')]),2,sum)
k=apply(is.na(dat1[,c(covs,'y')]),1,sum)
table(k)
cond=k==0
dat2=dat1[cond,]; dim(dat1); dim(dat2)
#dat2$cons_season=dat2$cons_season+1 #so that this can work as an index within JAGS
nparam=length(covs)
ntown=max(dat2$town.id)
cond=!is.na(dat2$cons_season) & dat2$cons_season!=0
dat3=dat2[cond,]; dim(dat2); dim(dat3)
#-------------------
#data for direct question (dq) non-sensitive (ns) item
cond=dat3$consumption_food_type=='bacaba' 
dq.ns=dat3[cond,]; dim(dq.ns) 
#season.dqns=dq.ns[,'cons_season']
y.dqns=dq.ns$y
table(y.dqns,useNA ='always')
n.dqns=length(y.dqns)
town.dqns=dq.ns$town.id
#-------------------
#data for indirect question (iq) sensitive item (si)
cond=dat3$consumption_food_type=='bacaba_wild_meat'; 
iq.si=dat3[cond,]; dim(iq.si) 
#season.iqsi=iq.si[,'cons_season']
y.iqsi=iq.si$y
table(y.iqsi,useNA ='always')
n.iqsi=sum(cond)
k=rep(1,n.iqsi)
town.iqsi=iq.si$town.id
#-------------------
#probability of answering sensitive question
pi.s=4/6

dat1=list(y.dqns=y.dqns,n.dqns=n.dqns,town.dqns=town.dqns,
          y.iqsi=y.iqsi,n.iqsi=n.iqsi,town.iqsi=town.iqsi,
          k=k,pi.s=pi.s,nparam=nparam,ntowns=ntown)

#set parameters to track
params=c('pi.nsi',"pi.si")

# MCMC settings 
n.iter <- 50000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 5000  

#fit the model
setwd('C:\\models_jags')
model=jags(model.file='logistic iq city high season.R',
           parameters.to.save=params,data=dat1,
           n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
           DIC=TRUE,parallel=TRUE)
summary(model)

#--------------------------------------------
setwd('C:\\results')

#look at results
res=model$summary
pi.estim=as.data.frame(res[,c('mean','2.5%','50%','97.5%','Rhat','overlap0')])

#export summary of results
write.csv(pi.estim,'pi logistic iq_wild_meat.csv')