# ASSESSES THE FACTORS ASSOCIATED WITH PROBABILITY OF CONSUMING WILDLIFE OR FISH CONSUMED IN 2018
## Direct method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)
table(dat[,c('consumption_now_2018','consumption_food_type')],useNA ='always') 

#focus on direct questions 
## food items:
# fish; turtle; wild_meat (wild_meat here refers to mammals and birds only)

ind=which(dat$consumption_food_type=='wild_meat')
dat1=dat[ind,] 
dat1$y=dat1$consumption_now_2018

#remove observations with missing data on covariates and/or responses
covs=c('years_in_town_total','age','ppi','n_people','children')

apply(is.na(dat1[,c(covs,'y')]),2,sum)
k=apply(is.na(dat1[,c(covs,'y')]),1,sum)
table(k)
cond=k==0
dat2=dat1[cond,]; dim(dat1); dim(dat2)
nparam=length(covs)
ntown=max(dat2$town.id)

#create design matrix
xmat.dqsi=dat2[,covs]
cor(xmat.dqsi,use="pairwise.complete.obs") #do we have correlation problems in covariates? No
nparam=length(covs)
ntown=max(dat2$town.id)

#get response, n, town.id
y.dqsi=dat2$y
n.dqsi=length(y.dqsi)
town.id.dqsi=dat2$town.id

#prepare data for jags
dat1=list(xmat.dqsi=xmat.dqsi, y.dqsi=y.dqsi,n.dqsi=n.dqsi,town.id.dqsi=town.id.dqsi,nparam=nparam,ntowns=ntown)

#set parameters to track
params=c("gamma.si",'int.gamma.si')

# MCMC settings 
n.iter <- 50000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 5000  

#fit the model
setwd('C:\\models_jags')
model=jags(model.file='logistic reg dq si.R',
           parameters.to.save=params,data=dat1,
           n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
           DIC=TRUE,parallel=TRUE)
summary(model)

setwd('C:\\results')

#look at results
res=model$summary
pi.estim=as.data.frame(res[,c('mean','2.5%','50%','97.5%','Rhat','overlap0')])

#export summary of results
write.csv(pi.estim,'pi logistic dq_wild_meat.csv')

# get posterior distribution
gamma.si=model$sims.list$gamma.si; colnames(gamma.si)=covs
int.gamma=model$sims.list$int.gamma
write.csv(gamma.si, "posterior_pi_param_dq_wild_meat.csv")
write.csv(int.gamma, "posterior_pi_intercept_wild_meat.csv")