# ASSESSES THE FACTORS ASSOCIATED WITH PROBABILITY OF CONSUMING WILDLIFE OR FISH CONSUMED IN 2018
## Indirect method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)
table(dat[,c('consumption_now_2018','consumption_food_type')],useNA ='always') 

#focus on indirect question
## food items:
# acai_fish; pamonha_turtle; bacaba_wild_meat (wild_meat here refers to mammals and birds only)

ind=which(dat$consumption_food_type%in%c('bacaba','bacaba_wild_meat'))
dat1=dat[ind,] 
dat1$y=dat1$consumption_now_2018
unique(dat1$consumption_food_type)

#--------------------------------------------
#remove observations with missing covariate and/or response variables
covs=c('years_in_town_total','age','ppi','n_people','children')

apply(is.na(dat1[,c(covs,'y')]),2,sum)
k=apply(is.na(dat1[,c(covs,'y')]),1,sum)
table(k)
cond=k==0
dat2=dat1[cond,]; dim(dat1); dim(dat2)
nparam=length(covs)
ntown=max(dat2$town.id)

#-------------------
#data for direct question (dq) non-sensitive (ns) item
cond=dat2$consumption_food_type=='bacaba' 
dq.ns=dat2[cond,]; dim(dq.ns) 
xmat.dqns=dq.ns[,covs]
y.dqns=dq.ns$y
table(y.dqns,useNA ='always')
n.dqns=length(y.dqns)
town.id.dqns=dq.ns$town.id
#-------------------
#data for indirect question (iq) sensitive item (si)
cond=dat2$consumption_food_type=='bacaba_wild_meat'; 
iq.si=dat2[cond,]; dim(iq.si) 
xmat.iqsi=iq.si[,covs]
y.iqsi=iq.si$y
table(y.iqsi,useNA ='always')
n.iqsi=sum(cond)
k=rep(1,n.iqsi)
town.id.iqsi=iq.si$town.id
#-------------------
#probability of answering sensitive question
pi.s=4/6

dat1=list(xmat.dqns=xmat.dqns, y.dqns=y.dqns,n.dqns=n.dqns,town.id.dqns=town.id.dqns,
          xmat.iqsi=xmat.iqsi, y.iqsi=y.iqsi,n.iqsi=n.iqsi,town.id.iqsi=town.id.iqsi,
          k=k,pi.s=pi.s,nparam=nparam,ntowns=ntown)

#set parameters to track
params=c('betas.nsi',"betas.si",'int.nsi','int.si')

# MCMC settings 
n.iter <- 50000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 5000  

#fit the model
setwd('C:\\models_jags')
model=jags(model.file='logistic now reg iq.R',
           parameters.to.save=params,data=dat1,
           n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
           DIC=TRUE,parallel=TRUE)
summary(model)

setwd('C:\\results')

#look at results
res=model$summary
pi.estim=as.data.frame(res[,c('mean','2.5%','50%','97.5%','Rhat','overlap0')])

#export summary of results
write.csv(pi.estim,'pi logistic iq_wild_meat.csv')

setwd('C:\\Users\\wchaves\\OneDrive - Virginia Tech\\Princeton_work\\Willa\\research_2018\\analysis\\analysis_method_paper\\models_methods_Ecological Applications\\results')

# get posterior distribution
betas.si=model$sims.list$betas.si; colnames(betas.si)=covs
int.si=model$sims.list$int.si
write.csv(betas.si, "posterior_pi_param_iq_wild meat.csv")
write.csv(int.si, "posterior_pi_intercept_iq_wild meat.csv")
